@@ -47,11 +47,23 @@ function enable() {
     winInjections['hideTooltip'] = undefined;
 
     Workspace.Workspace.prototype.showTooltip = function() {
-        if (this._tip == null)
+        if (this._tip == null || this._actualGeometry == null)
             return;
         this._tip.text = (this.metaWorkspace.index() + 1).toString();
-        this._tip.x = this._x;
-        this._tip.y = this._y;
+
+        // Hand code this instead of using _getSpacingAndPadding
+        // because that fails on empty workspaces
+        let node = this.actor.get_theme_node();
+        let padding = {
+            left: node.get_padding(St.Side.LEFT),
+            top: node.get_padding(St.Side.TOP),
+            bottom: node.get_padding(St.Side.BOTTOM),
+            right: node.get_padding(St.Side.RIGHT),
+        };
+
+        let area = Workspace.padArea(this._actualGeometry, padding);
+        this._tip.x = area.x;
+        this._tip.y = area.y;
         this._tip.show();
         this._tip.raise_top();
     }
@@ -206,7 +218,9 @@ function enable() {
         parentActor.add_actor(this._text);
     });
 
-    winInjections['updatePositions'] = injectToFunction(Workspace.WindowOverlay.prototype, 'updatePositions', function(cloneX, cloneY, cloneWidth, cloneHeight) {
+    winInjections['relayout'] = injectToFunction(Workspace.WindowOverlay.prototype, 'relayout', function(animate) {
+        let [cloneX, cloneY, cloneWidth, cloneHeight] = this._windowClone.slot;
+
         let textX = cloneX - 2;
         let textY = cloneY - 2;
         this._text.set_position(Math.floor(textX) + 5, Math.floor(textY) + 5);
@@ -251,6 +265,8 @@ function removeInjection(object, injection, name) {
 }
 
 function disable() {
+    let i;
+
     for (i in workspaceInjections)
         removeInjection(Workspace.Workspace.prototype, workspaceInjections, i);
     for (i in winInjections)
